@@ -116,7 +116,7 @@ class Carrier(BaseAgent):
             self.logger.error(ex)
             self.logger.error(traceback.format_exc())
             ret = {'processing_id': processing['processing_id'],
-                   'status': ProcessingStatus.Running,
+                   'status': ProcessingStatus.New,
                    'next_poll_at': datetime.datetime.utcnow() + datetime.timedelta(seconds=self.poll_time_period * 4)}
         return ret
 
@@ -554,7 +554,7 @@ class Carrier(BaseAgent):
 
             self.add_default_tasks()
 
-            task = self.create_task(task_func=self.get_new_processings, task_output_queue=self.new_task_queue, task_args=tuple(), task_kwargs={}, delay_time=1, priority=1)
+            task = self.create_task(task_func=self.get_new_processings, task_output_queue=self.new_task_queue, task_args=tuple(), task_kwargs={}, delay_time=60, priority=1)
             self.add_task(task)
             for _ in range(self.num_threads):
                 # task = self.create_task(task_func=self.process_new_processings, task_output_queue=self.new_output_queue, task_args=tuple(), task_kwargs={}, delay_time=1, priority=1)
@@ -563,7 +563,7 @@ class Carrier(BaseAgent):
             task = self.create_task(task_func=self.finish_new_processings, task_output_queue=None, task_args=tuple(), task_kwargs={}, delay_time=1, priority=1)
             self.add_task(task)
 
-            task = self.create_task(task_func=self.get_running_processings, task_output_queue=self.running_task_queue, task_args=tuple(), task_kwargs={}, delay_time=1, priority=1)
+            task = self.create_task(task_func=self.get_running_processings, task_output_queue=self.running_task_queue, task_args=tuple(), task_kwargs={}, delay_time=60, priority=1)
             self.add_task(task)
             for _ in range(self.num_threads):
                 # task = self.create_task(task_func=self.process_running_processings, task_output_queue=self.running_output_queue, task_args=tuple(), task_kwargs={}, delay_time=1, priority=1)
