@@ -25,5 +25,5 @@ conda activate $CondaDir
 export RUCIO_HOME=$RootDir
 export RUCIO_ACCOUNT=ddmadmin
 export X509_USER_PROXY=/tmp/x509up_u23959
-export PYTHONPATH=$PYTHONPATH:/cvmfs/atlas.cern.ch/repo/ATLASLocalRootBase/x86_64/rucio-clients/current/lib/python3.6/site-packages/
+# export PYTHONPATH=$PYTHONPATH:/cvmfs/atlas.cern.ch/repo/ATLASLocalRootBase/x86_64/rucio-clients/current/lib/python3.6/site-packages/
 
